@@ -1,2 +1,2 @@
-from .runners import *
 from zouqi import command, start
+from .runner import Runner
